NMCA - Unreported Decisions

New Mexico Court of Appeals – Unreported Memorandum Opinions – 2013
| This page contains memorandum opinions of the New Mexico Court of Appeals that were not selected for publication in the New Mexico Reports. Please see Rule 12-405 NMRA for restrictions on the citation of unpublished decisions. Please also note that these electronic decisions may contain computer-generated errors or other deviations from the official paper version filed by the Supreme Court and will not include the filing date. The filing date for each decision can be found in the table below.
| Sorting options — The decisions may be sorted by "Filing Date", "Short Title", or "Docket No."
| Click on the column name/header — the decisions will sort in descending/ascending order.
| Note that the Short Title column contains the full text of the decision in PDF format.
Filing Date | Short Title | Docket No.
--- | --- | ---
01/03/2013 | State v. Blair | 32,332
01/03/2013 | Gutierrez v. J. W. Drilling | 32,352
01/03/2013 | State v. Benavidez | 32,224
01/07/2013 | Van Auken v. Catron | 31,961
01/08/2013 | Standage Farms v. Lusk Onion | 32,362
01/09/2013 | State v. Bailee F. | 32,406
01/11/2013 | State v. Ferrell | 31,726
01/11/2013 | Cedrins v. Shrestha | 32,146
01/11/2013 | Fraternal Order of Police v. Alvarado | 30,900
01/14/2013 | E. Navajo Dine v. Environ. Dep't | 32,447
01/17/2013 | State v. Campbell | 32,462
01/17/2013 | State v. Hess | 31,536
01/18/2013 | State v. Miller | 32,034
01/22/2013 | State v. Wilson | 28,504
01/22/2013 | State v. Sekiya | 32,465
01/22/2013 | State v. Trujillo | 30,918
01/24/2013 | State v. Rodriguez | 31,079
01/28/2013 | Armijo v. Kohl's | 32,396
01/28/2013 | State v. Molina | 32,010
01/28/2013 | Torres v. Torres | 32,308
01/29/2013 | Enyeart v. Enyeart | 32,399
01/30/2013 | Gomez v. Wal-Mart Stores | 32,418
01/31/2013 | Mandeville v. Presbyterian Healthcare Svcs. | 32,441; 32,401
01/31/2013 | State v. Martinez | 32,271
02/01/2013 | State v. Castor | 31,819
02/04/2013 | Gomez v. Wal-Mart | 32,543
02/06/2013 | State v. Silva | 32,402
02/06/2013 | Englett v. Bee Hive Assisted Living | 32,195; 32,262
02/06/2013 | Discover Bank v. McGee | 32,257
02/06/2013 | Bransford-Wakefield v. Wakefield | 32,400
02/06/2013 | State v. Briseno | 31,393
02/06/2013 | Johnson v. Presbyterian Hospital | 32,394
02/07/2013 | Silva v. Smithkline | 31,276
02/07/2013 | Stone v. Smith | 32,583
02/08/2013 | State v. Morris | 31,815
02/08/2013 | Pargin Realty ERA v. Schmidt | 31,689
02/08/2013 | City of Belen v. Schueller | 32,483
02/08/2013 | State v. Vasquez | 32,528
02/08/2013 | Urias v. Blue Divot, Inc. | 32,463
02/08/2013 | State v. Ingram | 30,961
02/11/2013 | State v. Stapleton | 32,360
02/11/2013 | State v. Torres | 31,567
02/11/2013 | State v. Williams | 31,512
02/12/2013 | Wishneski v. Sanders | 32,371
02/12/2013 | Tan v. Barbeau | 32,392
02/12/2013 | Bank of Oklahoma N.A. v. Martinez | 32,481
02/13/2013 | Fuller v. DeLosier | 32,428
02/14/2013 | Hackett v. Wade | 32,386
02/14/2013 | Mendez v. Wells Fargo | 32,388
02/14/2013 | Deutsche Bank v. Van Rooyen | 32,341
02/14/2013 | Deutsche Bank v. Wilmot | 32,316
02/14/2013 | State v. Deleon | 30,813
02/18/2013 | Block v. Holiday Park | 31,845
02/18/2013 | Niec v. Clark | 32,560
02/18/2013 | State v. Littleton | 32,230
02/18/2013 | State v. Robinson | 32,344
02/20/2013 | Martinez v. Jones | 32,249
02/20/2013 | Clark v. Affinity Road & Travel | 32,507
02/20/2013 | Trujillo v. The GEO Group | 32,487
02/22/2013 | State v. Martinez | 32,424
02/26/2013 | State v. Baca | 31,340
02/26/2013 | State v. Lucero | 31,932
02/26/2013 | Turley v. Valdez | 31,404
02/27/2013 | State v. Knotts | 32,305
02/27/2013 | Purifoy v. Stone | 32,319
03/01/2013 | State v. Atwater | 31,218
03/01/2013 | State v. Garrison | 31,543
03/01/2013 | State v. Johnson | 30,793
03/01/2013 | Bowen v. Pyle | 32,358
03/04/2013 | State v. Zumwalt | 32,006
03/06/2013 | Derringer v. Derringer | 32,587
03/06/2013 | State v. Sekiya | 32,465
03/06/2013 | Polen v. Dotco | 32,538
03/07/2013 | State v. Hepple | 30,115
03/11/2013 | Alroy v. Board of Regents of UNM | 31,459
03/11/2013 | Chica Energy v. COG Operating | 32,608
03/11/2013 | State v. Towler | 32,484
03/11/2013 | State v. Olivas | 30,486
03/12/2013 | State v. Rambes | 31,515
03/12/2013 | Bank of Albuquerque v. Ambassador Development , LLC | 30,810
03/12/2013 | Saavedra v. Saavedra | 30,465
03/13/2013 | Tambourine v. Terminix Int'l Co. | 32,520
03/13/2013 | Butler Enters. v. Hi-Country Chevrolet | 32,627
03/14/2013 | Corliss v. Bond | 32,368
03/18/2013 | State v. Ketchum | 31,286
03/21/2013 | Barraza v. Albuquerque Heights Healthcare | 32,480
03/21/2013 | La Mesa Racetrack v. State of NM Racing Comm'n | 31,884
03/25/2013 | State v. Brown | 31,420
03/25/2013 | State v. Martinez | 32,496
03/25/2013 | Redman v. McClain Co. | 32,439
03/25/2013 | State v. Cortina | 30,317
03/25/2013 | Benavides v. Eastern NM Med Center | 32,450
03/26/2013 | State v. Valenzuela | 32,354
03/26/2013 | Ramirez v. Nieto | 32,646
03/26/2013 | State v. Samples | 32,364
03/26/2013 | State v. Hinojos | 32,234
03/26/2013 | State v. Swart | 31,486
03/26/2013 | Ruiz v. Los Lunas Pub. Schs. | 31,454
03/27/2013 | State v. Nelson | 31,664
03/27/2013 | State v. Ybanez | 31,216
03/28/2013 | State v. Carillo | 31,251
03/28/2013 | State v. Roybal | 32,576
03/28/2013 | State v. Smith | 32,645
03/28/2013 | State v. Reed | 32,491
04/01/2013 | State v. Tovar | 32,156; 32,518
04/01/2013 | Lopez v. Sandia Preparatory School | 32,449
04/01/2013 | Severns v. N.M. Taxation & Revenue | 31,817
04/01/2013 | Becerra v. Allstate | 32,456
04/01/2013 | Becerra v. Salazar | 32,393
04/01/2013 | State v. Barquist | 32,437
04/02/2013 | State v. Roman | 32,599
04/03/2013 | Austin Land Development v. Navajo Tribal Utility Authority | 32,601
04/03/2013 | State v. Lozano | 32,345
04/04/2013 | Jones v. Holiday Inn Express | 32,473
04/04/2013 | Green Tree Servicing, LLC v. Popovich | 32,527
04/04/2013 | State v. Vargas | 30,425
04/04/2013 | SW Energy Efficiency Project v. N.M. Constr. Comm'n | 31,383; 31,384; 31,385; 31,386
04/08/2013 | West v. Mazzola | 32,467
04/08/2013 | Dean v. Hompesch | 31,691
04/08/2013 | Madrid v. Brinker Restaurant Corp. | 31,244
04/09/2013 | State v. Begaye | 32,136
04/09/2013 | State v. Stallings | 32,228
04/09/2013 | Martinez v. Vigil-Martinez | 31,790
04/10/2013 | Eaton v. Jacobs | 32,478; 32,537
04/11/2013 | Castillo v. McCarthy Bldg. Companies | 30,939
04/15/2013 | Claude v. THI of New Mexico | 32,602
04/16/2013 | Ortiz v. Tozzoli | 32,397
04/16/2013 | Randall v. Pittman | 31,492
04/16/2013 | State v. Silva | 32,565
04/17/2013 | State v. Bruton | 32,452
04/17/2013 | Ginko v. Albuquerque Health Partners | 32,561
04/18/2013 | State v. Gunderson | 32,458
04/18/2013 | State v. Green | 31,885
04/18/2013 | State v. Soto-Tavison | 32,002
04/22/2013 | State v. McCulloch | 32,503
04/22/2013 | State v. Dean | 31,504
04/22/2013 | Padilla v. City of Albuquerque | 32,258
04/22/2013 | Griego v St. John Healthcare | 31,777
04/22/2013 | State v. Zamora | 32,459
04/22/2013 | State v. Gleason | 32,515
04/24/2013 | State v. Meeks | 31,587
04/24/2013 | State v. Armijo | 32,415
04/24/2013 | Redman v. The McClain Co. | 31,849
04/24/2013 | State v. Chavez | 29,810
04/25/2013 | State v. Rivera | 30,836
04/29/2013 | State v. Ramirez | 32,517
04/29/2013 | Leonard v. Leonard | 30,566
04/30/2013 | Byrne v. Byrne | 32,588
04/30/2013 | Elless v. Artesia General Hospital | 31,537